import express, {Request, Response} from 'express';
import {model, Schema, HydratedDocument} from 'mongoose';
import multer from 'multer';
import fs from 'fs';
import path from 'path';

const upload = multer({dest: 'uploads/artists'});
const router = express.Router();

export interface IArtist {
	name: string;
	image: File;
	description: string;
}

const artistSchema = new Schema<IArtist>({
	name: {
		type: String,
		required: true,
	},
	image: {
		data: Buffer,
		contentType: String,
	},
	description: {
		type: String,
		required: true,
	},
});

const Artist = model<IArtist>('Artist', artistSchema);

router.get('/', async (req: Request, res: Response) => {
	try {
		const artists = await Artist.find();
		res.send(artists);
	} catch (err: unknown) {
		res.send('could not get artists');
	}
});

router.post(
	'/',
	upload.single('image'),
	async (req: Request, res: Response) => {
		try {
			const artist: HydratedDocument<IArtist> = new Artist({
				name: req.body.name,
				description: req.body.description,
				image: {
					data: fs.readFileSync(
						path.join('uploads/artists/' + req.file?.filename)
					),
					contentType: 'image',
				},
			});
			await artist.save();

			res.send('Sucessfully saved');
		} catch (err: unknown) {
			res.send('Could not post');
		}
	}
);

export {router as artistRouter};
