import express, {Request, Response} from 'express';
import {model, Schema, HydratedDocument, Types} from 'mongoose';
import {IAlbum} from './albums';

const router = express.Router();

interface ITrack {
	name: string;
	album: Types.ObjectId;
	duration: string;
}

const Track = model<ITrack>(
	'Track',
	new Schema({
		name: String,
		duration: String,
		album: {
			type: Schema.Types.ObjectId,
			ref: 'Album',
		},
	})
);

router.get('/', async (req: Request, res: Response) => {
	if (!req.query.album) {
		try {
			const tracks = await Track.find().populate<{album: IAlbum}>('album');
			res.send(tracks);
			return;
		} catch (err: unknown) {
			res.send('Could not get tracks');
		}
	}
	try {
		const albumTracks = await Track.find({album: req.query.album});
		res.send(albumTracks);
	} catch (err: unknown) {
		res.send(`Could not find album tracks of ${req.query.album} `);
	}
});

router.post('/', async (req: Request, res: Response) => {
	try {
		const track: HydratedDocument<ITrack> = new Track({
			name: req.body.name,
			album: req.body.album,
			duration: req.body.duration,
		});
		await track.save();
		res.send(`Saved track: ${track}`);
	} catch (err: unknown) {
		res.send('Could not create track');
	}
});

export {router as trackRouter};
